@@ -28,7 +28,7 @@ import (
 	"k8s.io/client-go/rest"
 	"k8s.io/client-go/transport"
 	"k8s.io/client-go/util/retry"
-	"k8s.io/klog"
+	"k8s.io/klog/v2"
 	kcmdutil "k8s.io/kubectl/pkg/cmd/util"
 	"k8s.io/kubectl/pkg/util/templates"
 	"sigs.k8s.io/yaml"
@@ -39,11 +39,14 @@ import (
 	"github.com/openshift/library-go/pkg/image/dockerv1client"
 	imagereference "github.com/openshift/library-go/pkg/image/reference"
 	"github.com/openshift/library-go/pkg/manifest"
+	"github.com/openshift/library-go/pkg/verify"
+	"github.com/openshift/library-go/pkg/verify/store/configmap"
+	"github.com/openshift/library-go/pkg/verify/store/sigstore"
+	"github.com/openshift/library-go/pkg/verify/util"
 	"github.com/openshift/oc/pkg/cli/image/extract"
 	"github.com/openshift/oc/pkg/cli/image/imagesource"
 	imagemanifest "github.com/openshift/oc/pkg/cli/image/manifest"
 	"github.com/openshift/oc/pkg/cli/image/mirror"
-	"github.com/openshift/oc/pkg/helpers/release"
 )
 
 // configFilesBaseDir is created under '--to-dir', when specified, to contain release image
@@ -74,7 +77,7 @@ func NewMirrorOptions(streams genericclioptions.IOStreams) *MirrorOptions {
 //     --from=registry.svc.ci.openshift.org/openshift/v4.0 \
 //     --to=mycompany.com/myrepository/repo
 //
-func NewMirror(f kcmdutil.Factory, parentName string, streams genericclioptions.IOStreams) *cobra.Command {
+func NewMirror(f kcmdutil.Factory, streams genericclioptions.IOStreams) *cobra.Command {
 	o := NewMirrorOptions(streams)
 	cmd := &cobra.Command{
 		Use:   "mirror",
@@ -112,26 +115,26 @@ func NewMirror(f kcmdutil.Factory, parentName string, streams genericclioptions.
 			and indicates to update an exisiting ConfigMap if one is found. A ConfigMap written to a
 			directory will always replace onethat already exists.
 		`),
-		Example: templates.Examples(fmt.Sprintf(`
+		Example: templates.Examples(`
 			# Perform a dry run showing what would be mirrored, including the mirror objects
-			%[1]s mirror 4.3.0 --to myregistry.local/openshift/release \
+			oc adm release mirror 4.3.0 --to myregistry.local/openshift/release \
 				--release-image-signature-to-dir /tmp/releases --dry-run
 
 			# Mirror a release into the current directory
-			%[1]s mirror 4.3.0 --to file://openshift/release \
+			oc adm release mirror 4.3.0 --to file://openshift/release \
 				--release-image-signature-to-dir /tmp/releases
 
 			# Mirror a release to another directory in the default location
-			%[1]s mirror 4.3.0 --to-dir /tmp/releases
+			oc adm release mirror 4.3.0 --to-dir /tmp/releases
 
 			# Upload a release from the current directory to another server
-			%[1]s mirror --from file://openshift/release --to myregistry.com/openshift/release \
+			oc adm release mirror --from file://openshift/release --to myregistry.com/openshift/release \
 				--release-image-signature-to-dir /tmp/releases
 
 			# Mirror the 4.3.0 release to repository registry.example.com and apply signatures to connected cluster
-			%[1]s mirror --from=quay.io/openshift-release-dev/ocp-release:4.3.0-x86_64 \
+			oc adm release mirror --from=quay.io/openshift-release-dev/ocp-release:4.3.0-x86_64 \
 				--to=registry.example.com/your/repository --apply-release-image-signature
-			`, parentName)),
+		`),
 		Run: func(cmd *cobra.Command, args []string) {
 			kcmdutil.CheckErr(o.Complete(cmd, f, args))
 			kcmdutil.CheckErr(o.Validate())
@@ -236,7 +239,7 @@ func (o *MirrorOptions) Complete(cmd *cobra.Command, f kcmdutil.Factory, args []
 		if err != nil {
 			return nil, err
 		}
-		client := coreClient.ConfigMaps(release.NamespaceLabelConfigMap)
+		client := coreClient.ConfigMaps(configmap.NamespaceLabelConfigMap)
 		return client, nil
 	}
 	o.PrintImageContentInstructions = true
@@ -321,7 +324,7 @@ func (o *MirrorOptions) handleSignatures(context context.Context, signaturesByDi
 		}
 	}
 	for digest, signatures := range signaturesByDigest {
-		cmData, err := release.GetSignaturesAsConfigmap(digest, signatures)
+		cmData, err := verify.GetSignaturesAsConfigmap(digest, signatures)
 		if err != nil {
 			return fmt.Errorf("converting signatures to a configmap: %v", err)
 		}
@@ -360,7 +363,7 @@ func (o *MirrorOptions) handleSignatures(context context.Context, signaturesByDi
 			if o.DryRun {
 				fmt.Fprintf(o.Out, "info: Write configmap signature file %s\n", fullName)
 			} else {
-				cmDataBytes, err := yaml.Marshal(cmData)
+				cmDataBytes, err := util.ConfigMapAsBytes(cmData)
 				if err != nil {
 					return fmt.Errorf("marshaling configmap YAML: %v", err)
 				}
@@ -497,11 +500,11 @@ func (o *MirrorOptions) Run() error {
 	sourceFn := func(ref imagesource.TypedImageReference) imagesource.TypedImageReference {
 		return ref
 	}
-	// Wraps operator's HTTPClient method to allow image verifier to create http client with up-to-date config
-	clientBuilder := &verifyClientBuilder{builder: o.HTTPClient}
+
+	httpClientConstructor := sigstore.NewCachedHTTPClientConstructor(o.HTTPClient, nil)
 
 	// Attempt to load a verifier as defined by the release being mirrored
-	imageVerifier, err := release.LoadConfigMapVerifierDataFromUpdate(manifests, clientBuilder, nil)
+	imageVerifier, err := verify.NewFromManifests(manifests, httpClientConstructor.HTTPClient)
 	if err != nil {
 		return fmt.Errorf("Unable to load configmap verifier: %v", err)
 	}
@@ -509,7 +512,7 @@ func (o *MirrorOptions) Run() error {
 		klog.V(4).Infof("Verifying release authenticity: %v", imageVerifier)
 	} else {
 		fmt.Fprintf(o.ErrOut, "warning: No release authenticity verification is configured, all releases are considered unverified\n")
-		imageVerifier = release.Reject
+		imageVerifier = verify.Reject
 	}
 	// verify the provided payload
 	ctx, cancelFn := context.WithCancel(context.Background())
